classdef DatasetLoaderToulouse

    properties
        datasetPath
        imageNames
        count
        focal
        pp
    end
    
    methods
        
        function obj = DatasetLoaderToulouse()
            % Constructor, load common data
            datasetPath = textread('dataset_toulouse_path.ini','%s\n');
            obj.datasetPath = datasetPath{1};
            if length(obj.datasetPath) < 1
                error('Please configure the path of the Toulouse dataset in the file dataset_toulouse_path.ini');
            end
            files = dir(fullfile(obj.datasetPath, '*.jpg'));
            obj.imageNames = {};
            j = 1;
            for i=1:length(files)
                if ~files(i).isdir
                    obj.imageNames{j} = files(i).name(1:end-4);
                    j = j + 1;
                end
            end
            obj.count = length(obj.imageNames);
            if obj.count < 1
                error(strcat('No image found in the folder ', obj.datasetPath));
            end
        end
        
        function imageData=getImageDataAtIndex(obj, index)
            % Load the indexth image, lines and intrinsics
            % Return a struct imageData with the fields: 
            %   K: camera intrinsics parameters (depends on image orientation)
            %   Kinv: Kinv
            %   img: image
            %   lines: gt lines segments in the format nx4 with lines(i,:) are the x,y coordinates of the two endpoints
            %   linesEq: gt lines equations 
            %   name: image name
            %   vp_association: to which vp a line is associated with
            %   R_imu : imu data
            if index > obj.count
                error('index is out of bound');
            end
            imageName = obj.imageNames{index};
            imageData = obj.getImageDataAtImageName(imageName);
        end
  
       function imageData=getImageDataAtImageName(obj, imageName)
            % Load files
            imagePath = fullfile(obj.datasetPath, strcat(imageName, '.jpg'));
            imageData.name = imageName;
            imageData.img = imread(imagePath);
            imageData.polys = {{},{},{}};
%             try
                % TEMP HACK. Note there is a well-known Matlab bug with run. If you modify the run script, a second run
                % will not run the modifications!
%                 try
%                     run(fullfile( obj.datasetPath,  imageName ));
%                 catch
%                     segments = [];
%                     vp_association = [];
%                 end
                load(fullfile( obj.datasetPath,  imageName ));
                imageData.lines = double(segments);
                imageData.polys = polys;
                imageData.vp_association = vp_association;
%                 imageData.lines = [];
%                 imageData.vp_association = [];
                Kacc = [11.5 0 10 ; 0 11.5 8.3 ; 0 0 1];
                K = [1757.20778                       0             974.82294 ; ...
                              0              1753.24412             546.29704 ; ...
                              0                       0                     1];
%                 K = [1736.55811                     0             959.27081 ; ...
%                               0            1737.39094             566.25983 ; ...
%                               0                     0                     1];
%             catch
%                 warning('MISSING .mat file. We are using predefined DEBUG data');
%                 imageData.lines = [];
%                 imageData.vp_association = [];
%                 R_imuRaw = reshape([0.999312, 0.022657, -0.029319, -0.026538, -0.114586, -0.993058, -0.025860, 0.993154, -0.113907], 3, 3)';
%                 R_imu = reshape([0.999286, 0.023127, -0.029884, -0.027071, -0.113629, -0.993154, -0.026365, 0.993254, -0.112922], 3, 3)';
%                 Kacc = zeros(3, 3);
%                 K = [1736.55811                     0             959.27081 ; ...
%                               0            1737.39094             566.25983 ; ...
%                               0                     0                     1];
%                 
%             end
            
            % Compute line equations ax + by + cz = 0 form the lines endpoints
            n = size(imageData.lines, 1);
            linesEq = zeros(n, 3);
            for i=1:n
                linesEq(i,:) = cross([imageData.lines(i,1:2) 1], [imageData.lines(i,3:4) 1]);
            end
            imageData.linesEq = linesEq;
            % Length2
            imageData.lineLength2 = dot(linesEq(:,1:2)', linesEq(:,1:2)')';
            % Clean up
            nullSegments = imageData.lineLength2 < eps;
            imageData.vp_association(nullSegments) = -1; % Remove the segment without changing the index
            % Intrinsics
            imageData.K = K;
            imageData.Kacc = Kacc;
            imageData.Kinv = inv(K);
            % IMU data
            imageData.R_imu = mean_rot;
%             imageData.R_imuRaw = raw_rot;
            

       end
    end
end
