%% Using the dataset

%% Loading

% Take account of all folders and subfolders of code
init;

% Helper class to load a photo, the ground truth line segment, camera parameters, IMU data, compute the line equations
% from the segments, ...
d=DatasetLoaderToulouse();

% Access ImageData by index (here we ask to retrieve the 1st photo and associated data of the dataset).
imgData = d.getImageDataAtIndex(3);

% Alternative: access ImageData by the name of the photo
imgData = d.getImageDataAtImageName('img_1295');

width = size(imgData.img, 2);
height = size(imgData.img, 1);

%% Details on the data

% The img (just printing the size here
size(imgData.img)

% The camera intrinsics
K = imgData.K

% The line segments
lines = imgData.lines

% The lines associated to the lines
linesEq = imgData.linesEq

% The name of the image
name = imgData.name

% The rotation privided by the IMU
R_imu = imgData.R_imu

% Vanishing point associated with each of the n line segments
vp_association = imgData.vp_association


%% Display


axis([1 width 1 height]);
color = ['r', 'g', 'b'];

hold on;
imagesc(imgData.img);

% Display the ground truth line segments
for i=1:size(imgData.lines,1)
    plot(imgData.lines(i,[1,3]), imgData.lines(i,[2,4]), color(imgData.vp_association(i)));
    hline(cross([imgData.lines(i,1:2) 1]', [imgData.lines(i,3:4) 1]'), 'LineStyle', '--', 'Color', color(imgData.vp_association(i)));
end

% Display the horizon and the zenith compute from the IMU data 
zenith  = imgData.K * imgData.R_imu * [0 ; 0 ; -1];
zenith  = zenith / zenith(3);
horizon = imgData.Kinv' * imgData.R_imu * [0 ; 0 ; -1];
pzenith = plot( zenith(1), zenith(2), 's', 'LineWidth',1, 'MarkerEdgeColor','k', 'MarkerFaceColor', 'c', 'MarkerSize',6);
phorizon = hline(horizon, 'color', 'c', 'LineWidth',2);

legend(gca, [pzenith, phorizon], 'Zenith (IMU)', 'Horizon (IMU)');
axis ij;
hold off;
