# Vanishing regions

These functions enable to compute the vanishing regions (polygons) of a scene containing clustered segments.
It takes into account an uncertainty parameter which is an upper bound of the errors commited while creating the ground truth line segments.
The regions are computed by intersecting double wedges created from the segments.

## Code organization

### Core

#### computeLineInfinitePoint.m
Compute one of the infinite point associated to a line.

#### doubleWedgesIntersection.m
Compute the intersection of the double wedges of the segments.

#### mergePolygons.m
Merge two polygons splited by the line at infinity into one polygon.

#### PolyEstimator.m
Utility class to compute, save and load the results.

#### segmentToDoubleWedge.m
Compute the double wedge associated to a segment wrt to a given accuracy.


### Display
#### bestPolygonsAxis.m
Compute the best axis to display all the finite points of polygons in the image space.

#### infinitePolygonAxisFit.m
Compute a new polygon which can be displayed in the image space given the provided axis.

### Verification

#### isPointInDoubleWedge.m
Check whether a point is in a double-wedge

#### isPointInDoubleWedgesIntersection.m
Check whether a point is in the intersection of double wedges

#### polygonEqual.m
Compare two polygons. Two polygons are equal if they have the same vertices at a given circular shift of the rows composed with at most one inversion.

#### polygonsEqual.m
Ensure two cell arrays of polygons contain the same polygons, whatever their orders in the cell arrays.

#### polygonVerification.m
Advanced double wedge intersections verification.

#### testDoubleWedgesIntersection
Unitary tests for checking doubleWedgesIntersection, polygonEqual and polygonsEqual.

#### verifyDoubleWedgesIntersection.m
Brute force verification. A uniform sampling is taken.

#### verifyDoubleWedgesIntersectionOnPolygonEdges.m 
Check whether the points on the edges of a polygon are is in the intersection of the double-wedges (which we expect to be the same polygon).
