classdef PolyEstimator
    % Compute, save and load the results.

    properties
        name
        polys
        mergedpolys
        maxNoise
    end
    
    methods
        
        function obj = PolyEstimator()
            obj.name = 'PolyEstimator';
            obj.polys = {};
            obj.mergedpolys = {};
            oj.maxNoise = 0;
        end
        
        function [polys, mergedpolys, maxAccuracy] = compute_polys(obj, imageData, accuracy)
            % Compute the double wedge intersections of a set of segments provided from an imageData object.
            % Use doubleWedgesIntersection() to compute the intersection.
            % Automatically increase the accuracy/uncertainty value when the intersection is empty.
            if nargin <= 2
                accuracy = 2;
            end
     
            polys = {};
            mergedpolys = {};
            maxAccuracy = accuracy;
            accuracyLimit = 16;

            for i=1:3
                currentAccuracy = accuracy;
                mergedPoly = [];
                while currentAccuracy <= accuracyLimit && size(mergedPoly, 1) == 0
                    polygons = doubleWedgesIntersection(imageData.lines(imageData.vp_association==i,:), currentAccuracy);
                    mergedPoly = mergePolygons(polygons);
                    maxAccuracy = max(maxAccuracy, currentAccuracy);
                    currentAccuracy  = currentAccuracy + 1;
                    if maxAccuracy == accuracyLimit
                        error(sprintf('We have less than %d accuracy for the %d cluster of segments', accuracyLimit, i));
                    end
                    polys{i} = polygons;
                    mergedpolys{i} = mergedPoly;
                end
            end
            if maxAccuracy > accuracy
                warning(sprintf('The lines seems not enough accurate to require a noise of %d', maxAccuracy));
            end
        end
        
        function save(obj)
            save(['res/polys_ref_' imageData.name, '.mat'], 'obj.polys', 'obj.mergedpolys', 'obj.maxNoise');
        end
       
        function [polys, ortho_polys, maxNoise]=load_polys(obj, name)
            load(['res/polys_ref_' name, '.mat']);
        end
    end
end