function currentAxes=bestPolygonsAxis(currentAxes, polygons)
    % Compute the best axis to display all the finite points of polygons in the image space.
    % Note some finite vertices may be close of the line at infinity ...
    % INPUT
    %   currentAxes 1x4 double the axis of the figure
    %   polygons    cell array of polygons. Each polygon is a mx3 double matrix of m points represented in homogeneous coordinates.
    % OUTPUT
    %   currentAxes 1x4 the axes which enable to display all the finite vetices of the polygons
    min_x = -10;
    max_x = 10;
    min_y = -10;
    max_y = 10;
    for i=1:size(polygons,2)
        poly = polygons{i};
        nonInfPts = abs(poly(:,3)) > eps;
        % We may have negative z, so we normalize:
        poly(nonInfPts,:) = poly(nonInfPts,:) ./ (poly(nonInfPts,3) * ones(1,3));
        currentAxes(1) = min([poly(nonInfPts,1); currentAxes(1)]);
        currentAxes(2) = max([poly(nonInfPts,1); currentAxes(2)]);
        currentAxes(3) = min([poly(nonInfPts,2); currentAxes(3)]);
        currentAxes(4) = max([poly(nonInfPts,2); currentAxes(4)]);
    end
end