function newPoly=infinitePolygonAxisFit(poly, axes)
    % Compute a new polygon which can be displayed in the image space given the provided axis.
    % If vertices are infinite points, they are not displayed, but the edges going to these infinite points are
    % displayed.
    % Known bug: when the edges going to one infinite point are cutting two different boundaries of the image (axis),
    % the edges are not properly displayed.

    if nargin <= 1
        axes = axis;
    end
    
    idxNotInf = abs(poly(:,3)) > eps;
    poly(idxNotInf,:) = poly(idxNotInf,:) ./ (poly(idxNotInf,3) * ones(1,3));

    borderSegments = [axes(1) axes(3) axes(1) axes(4) ; ...
                      axes(2) axes(3) axes(2) axes(4) ; ...
                      axes(1) axes(3) axes(2) axes(3) ; ...
                      axes(1) axes(4) axes(2) axes(4)];
              
    newPoly = [];
    for j=1:size(poly,1)
        if abs(poly(j,3)) > eps
          newPoly = [newPoly ; poly(j,:)];
        else
          % We found an infinite point in this polygon
          jPrev = mod(j-1 -1, size(poly,1)) + 1;
          jNext = mod(j+1 -1, size(poly,1)) + 1;
          for jj = [jPrev jNext]
              if poly(jj, 3) > eps
                  % d is the ray from poly(jj, :) (finite) to poly(j,:) (infinite)
                  d = cross(poly(jj, :), poly(j,:));
                  for k=1:4
                      % Compute the intersection between the ray d and the segment borderSegments(k,:) if it exists
                      borderSegP1 = borderSegments(k,1:2);
                      borderSegP2 = borderSegments(k,3:4);
                      borderSegLine = cross([borderSegP1 1], [borderSegP2 1]);
                      if dot(borderSegP1, d(1:2)) * dot(borderSegP2, d(1:2)) < 0 ...
                              && dot(borderSegLine, poly(jj, :)) * dot(borderSegLine, poly(j, :)) < 0
                          % We found a segment of the border which is intersected
                          intersBorder = cross(d, borderSegLine);
                          newPoly = [newPoly ; intersBorder / intersBorder(3)];
                          break;
                      end
                  end
              end
          end
        end
    end
end