function isEqual=polygonEqual(poly1, poly2)
    % Compare two polygons. Two polygons are equal if they have the same vertices at a given circular shift of the rows
    % composed with at most one inversion.
    % Eg [0 0 1 ; 1 0 1 ; 1 1 1] == [1 1 1 ; 0 0 1 ; 1 0 1]
    % INPUT: 
    %   poly1  nx4 double   1st polygon with n vertices represented in homogeneous coordinates
    %   poly2  mx4 double   2nd polygon with m vertices represented in homogeneous coordinates
    % OUTPUT:
    %   isEqual boolean     true when the polygons are equals.
    nVerts2 = size(poly2, 1);
    isEqual = norm(size(poly1) - size(poly2)) < eps;
    if ~isEqual
        return;
    end
    % We search for the circular shift of the rows
    firstV1Idx = find(ismember(abs(poly2 - ones(nVerts2,1)*poly1(1,:)) < 1e-5, ones(1,size(poly2, 2)), 'rows'));
    isEqual = length(firstV1Idx) >= 1;
    if ~isEqual
        return;
    end
    firstV1Idx = firstV1Idx(1);
    poly2_1 = poly2(mod([1:nVerts2]+firstV1Idx-2,nVerts2)+1,:);
    % Try the inversion
    poly2_2 = poly2_1(end:-1:1,:);
    poly2_2 = poly2_2(mod([1:nVerts2]+nVerts2-2,nVerts2)+1,:);
    isEqual = norm(poly1-poly2_1) < 1e-5 || norm(poly1-poly2_2) < 1e-5;
end