function polygonVerification(imgData, axes, polys, resX, resY, accuracy)
    % More advanced verification:
    % we sample on the edges and make a random sampling too.
    % Point inside the intersection are in green, outside in red.
    % The user should visually check the color of the points is consistent with the polygons.
    figure;
    colors = [1 0 0 ; 0 1 0];
    for i=1:size(polys,2)
        subAxe = subplot(2, 2, i);
        hold on
        lines = imgData.lines(imgData.vp_association==i,:);
        % Verificaton on edges
        exteriorInterior = {[], []};
        for iPoly=1:size(polys{i},2)
            % Plot computed polygon
            poly = infinitePolygonAxisFit(polys{i}{iPoly}, axes{i});
            poly = poly([1:end,1],:); % Repeat last vertex
            plot(poly(:,1), poly(:,2));
            
            extIn = verifyDoubleWedgesIntersectionOnPolygonEdges(axes{i}, resX, resY, lines, accuracy, poly);
            exteriorInterior{1} = [exteriorInterior{1} ; extIn{1}];
            exteriorInterior{2} = [exteriorInterior{2} ; extIn{2}];
        end
        % Monte-Carlo verification (random points)
        axe = axes{i};
        randomNumbers = 30;
        randX = axe(1) + (axe(2) - axe(1))*rand(1, randomNumbers);
        randY = axe(3) + (axe(4) - axe(3))*rand(1, randomNumbers);
        for coord = [randX ; randY]
            res = isPointInDoubleWedgesIntersection([coord' 1], lines, accuracy);
            exteriorInterior{int8(res)+1} = [exteriorInterior{int8(res)+1} ; coord'];
        end
        % Results
        for i=1:2
            if size(exteriorInterior{i}, 1) > 0
                plot(exteriorInterior{i}(:,1), exteriorInterior{i}(:,2), 'x', 'Color', colors(i,:));
            end
        end
        axis ij;
        hold off
    end
    set(gcf, 'units','normalized','outerposition',[0 0 1 1]); % Figure on full screen
    set(gcf,'PaperPositionMode','auto');
    print('-dpng','-r100', [imgData.name, '_verif']);
end