function testDoubleWedgesIntersection()
    % Unitary tests for checking doubleWedgesIntersection, polygonEqual and polygonsEqual
    
    % Test polygonEqual
    polyMagic = magic(7);
    assert(polygonEqual(polyMagic, polyMagic(end:-1:1,:)));
    assert(polygonEqual(polyMagic, polyMagic(mod([1:end]+5,7)+1,:)));
    assert(~polygonEqual(polyMagic, [1:7]));
    assert(~polygonEqual(polyMagic, ones(7,7)));
    
    % Test polygonsEqual
    assert(polygonsEqual({1, 2, 4, 4}, {4, 1, 4, 2}));
    assert(~polygonsEqual({1, 2, 4, 4}, {4, 1, 2}));
    assert(~polygonsEqual({1, 2, 4, 4}, {3, 4, 1, 2}));
    
    % Test doubleWedgesIntersection
    % Test1
    segments = [0 -10 0 10 ; 0.30 -40 0.30 40];
    poly1 = [         0.24                       1.2                         1 ; ...
                       0.4                         2                         1 ; ...
                      0.05                         1                         0 ; ...
                     -0.05                         1                         0];
                 
    poly2 = [          0.4                        -2                         1 ; ...
                      0.24                      -1.2                         1 ; ...
                     -0.05                        -1                         0 ; ...
                      0.05                        -1                         0];
   polys = doubleWedgesIntersection(segments);
   assert(polygonsEqual({poly1, poly2}, polys));
   
   % Test2
   segments = [0 0 10 0 ; 0 4 10 4];
   poly1  = [          2.5                         1                         0 ; ...
                        10                         2                         1 ; ...
                       2.5                        -1                         0];

   poly2 = [          -2.5                        -1                         0 ; ...
                         0                         2                         1 ; ...
                      -2.5                         1                         0];
   polys = doubleWedgesIntersection(segments);
   assert(polygonsEqual({poly1, poly2}, polys));
   
   % Test3
   segments = [0 0 0 10 ; 4 0 4 6];
   poly1 = [          -0.4                         1                         0 ; ...
                        -4                        15                         1 ; ...
                         1                       7.5                         1 ; ...
                       0.4                         1                         0];

   poly2 = [           0.4                        -1                         0 ; ...
                         2                         0                         1 ; ...
                        -8                       -15                         1 ; ...
                      -0.4                        -1                         0];
   polys = doubleWedgesIntersection(segments);
   assert(polygonsEqual({poly1, poly2}, polys));
   
   % Test4
   segments = [0 0 0 10 ; 4 0 5 10];
   poly1 = [2.62158521797448          11.5539630449362                         1 ; ...
                         0.4                         1                         0 ; ...
          -0.286607472325748                         1                         0];

   poly2 = [15.8740618709104          -34.685154677276                         1 ; ...
            1.95937935371929         0.101551615701781                         1 ; ...
           -15.1696157939519         -32.9240394848797                         1 ; ...
                        -0.4                        -1                         0 ; ...
           0.286607472325748                        -1                         0];
   polys = doubleWedgesIntersection(segments);
   assert(polygonsEqual({poly1, poly2}, polys));
   
   % Test 5
   segments = [0 0 0 10 ; 4 0 4 10];
   poly1 = [-0.4                         1                         0
               2                        10                         1
             0.4                         1                         0];

   poly2 = [0.4                        -1                         0
              2                         0                         1
           -0.4                        -1                         0];
   polys = doubleWedgesIntersection(segments);
   polygonsEqual({poly1, poly2}, polys);
end