function exteriorInterior = verifyDoubleWedgesIntersectionOnPolygonEdges(axes, resX, resY, segments, accuracy, polygon)
    % Check whether the points on the edges of a polygon are is in the intersection of the double-wedges (which we
    % expect to be the same polygon)
    % INPUT
    %   axes: 1x4 bounding box of the polygon [x_min, x_max, y_min, y_max]
    %   resX : maximum number of point tested on the X axis
    %   resY : maximum number of point tested on the Y axis
    %   segments: nx4 list, segments defining the double wedges with the noise
    %   noise: (extremity uncertainty)
    %   polygon: expected intersection
    % OUTPUT
    %   exteriorInterior: exteriorInterior{1} contains the points in the exterior of the intersection
    %                     exteriorInterior{2} contains the points in the interior of the intersection
    exteriorInterior = {[], []};
    for i=1:size(polygon, 1)
        % iNext is the successor of i
        iNext = mod(i, size(polygon, 1)) + 1;
        % e1, e2 are the coordinates of the segment endpoint in a coordinate system defined by axes after a scaling
        % defined by resX et resY
        e1 = polygon(i,1:2);
        e2 = polygon(iNext,1:2);
        e1(1) = (e1(1) - axes(1))/(axes(2)-axes(1)) * resX;
        e1(2) = (e1(2) - axes(3))/(axes(4)-axes(3)) * resY;
        e2(1) = (e2(1) - axes(1))/(axes(2)-axes(1)) * resX;
        e2(2) = (e2(2) - axes(3))/(axes(4)-axes(3)) * resY;
        [x, y] = bresenham([e1  e2]);
        % Back in the orginal axis
        x = (axes(2)-axes(1)) * x / resX + axes(1);
        y = (axes(4)-axes(3)) * y / resY + axes(3);
        coords = [x ; y];
        for coord = coords
            % For each point of the edge, check wheter it is inside or outside the intersection and store the result
            res = isPointInDoubleWedgesIntersection([coord' 1], segments, accuracy);
            exteriorInterior{int8(res)+1} = [exteriorInterior{int8(res)+1} ; coord'];
        end
    end
% % DEBUG
%     hold on
%     for i=1:2
%         plot(exteriorInterior{i}(:,1), exteriorInterior{i}(:,2), 'x', 'Color', colors(i,:));
%     end
%     hold off
end